==> sentinel.v2.1.tar.gz: Sentinel/tools/www/sentinel.php <==
<?php
/*
 *  $Id: sentinel.php,v 1.3 2003/05/18 00:48:04 wcampbel Exp $
 */

// MySQL Database
$mysql_server = "mysql.server";
$mysql_db     = "sentinel";
$mysql_user   = "user";
$mysql_passwd = "password";
$server_id = (isset($HTTP_GET_VARS['server'])) ? $HTTP_GET_VARS['server'] : '';

$idsql = mysql_connect($mysql_server, $mysql_user, $mysql_passwd);
mysql_select_db($mysql_db);
?>
<html>
<head>
<title>Sentinel Statistics</title>
<style type=text/css>
body { background-color: #E5E5E5; }
font,th,td,p { font-family: Verdana, Arial, Helvetica, sans-serif }
a:link,a:active,a:visited { text-decoration: none; color : #006699; }
a:hover { text-decoration: underline; color : #DD6900; }
.bodyline { background-color: #FFFFFF; border: 1px #98AAB1 solid; }
.maintitle { font-weight: bold; font-size: 22px; font-family: "Trebuchet MS",Verdana, Arial, Helvetica, sans-serif; text-decoration: none; line-height : 120%; color : #000000; }
.hline { background-color: #FFFFFF; border: 2px #006699 solid; }
.gen { font-size : 11px; color : #000000; }
td.row1	{ background-color: #EFEFEF; }
td.row2	{ background-color: #DEE3E7; }
td.row3	{ background-color: #D1D7DC; }
th { color: #FFA34F; font-size: 11px; font-weight : bold; background-color: #006699; height: 17px; background-image: url(img/cellpic.gif); }
th.thCornerL { border-width: 1px 0px 0px 1px; }
th.thCornerR { border-width: 1px 1px 0px 0px; }
</style>
</head>
<body bgcolor="#e5e5e5" text="#000000">
<center>
<table width="100%" cellspacing="0" cellpadding="10" border="0" align="center">
  <tbody>
  <tr>
    <td class="bodyline">
      <table cellSpacing=0 cellPadding=0 width="100%" border=0>
        <tbody>
        <tr>
          <td align="center"><span class="maintitle">
          <?php if (isset($HTTP_GET_VARS['server']))
                  echo("Sentinel Server $server_id Statistics");
                else
                  echo("Sentinel Network Statistics");
          ?>
          </span></td>
        </tr>
        </tbody>
      </table>
      <br>
      <table class="hline" cellSpacing="1" cellPadding="2" width="100%" border="0">
        <tbody>
<?php
if (isset($HTTP_GET_VARS['server']))
{
  echo("<tr><th class=\"thCornerL\" align=\"middle\" width=\"80%\" height=\"17\">Field</th>");
  echo("<th class=\"thCornerR\" align=\"middle\" height=\"17\">Value</th></th>");

  $result = mysql_query("SELECT * FROM server WHERE name='$server_id' ORDER BY users DESC");

  $server = mysql_fetch_row($result);

  $ninvis = abs($server[17] - $server[2]);

  echo("<tr><td class=\"row1\" align=\"left\" height=\"17\"><span class=\"gen\">Current users</span></td>\n");
  echo("<td class=\"row2\" align=\"middle\" height=\"17\"><span class=\"gen\">$server[2]</span></td></tr>\n");
  echo("<tr><td class=\"row1\" align=\"left\" height=\"17\"><span class=\"gen\">Max users</span></td>\n");
  echo("<td class=\"row2\" align=\"middle\" height=\"17\"><span class=\"gen\">$server[3]</span></td></tr>\n");
  echo("<tr><td class=\"row1\" align=\"left\" height=\"17\"><span class=\"gen\">Invisible users (+i)</span></td>\n");
  echo("<td class=\"row2\" align=\"middle\" height=\"17\"><span class=\"gen\">$server[17]</span></td></tr>\n");
  echo("<tr><td class=\"row1\" align=\"left\" height=\"17\"><span class=\"gen\">Not invisible users (-i)</span></td>\n");
  echo("<td class=\"row2\" align=\"middle\" height=\"17\"><span class=\"gen\">$ninvis</span></td></tr>\n");
  echo("<tr><td class=\"row1\" align=\"left\" height=\"17\"><span class=\"gen\">Away users</span></td>\n");
  echo("<td class=\"row2\" align=\"middle\" height=\"17\"><span class=\"gen\">$server[14]</span></td></tr>\n");
  echo("<tr><td class=\"row1\" align=\"left\" height=\"17\"><span class=\"gen\">Max away users</span></td>\n");
  echo("<td class=\"row2\" align=\"middle\" height=\"17\"><span class=\"gen\">$server[15]</span></td></tr>\n");
  echo("<tr><td class=\"row1\" align=\"left\" height=\"17\"><span class=\"gen\">Current opers</span></td>\n");
  echo("<td class=\"row2\" align=\"middle\" height=\"17\"><span class=\"gen\">$server[5]</span></td></tr>\n");
  echo("<tr><td class=\"row1\" align=\"left\" height=\"17\"><span class=\"gen\">Max opers</span></td>\n");
  echo("<td class=\"row2\" align=\"middle\" height=\"17\"><span class=\"gen\">$server[6]</span></td></tr>\n");
  echo("<tr><td class=\"row1\" align=\"left\" height=\"17\"><span class=\"gen\">Oper kills</span></td>\n");
  echo("<td class=\"row2\" align=\"middle\" height=\"17\"><span class=\"gen\">$server[9]</span></td></tr>\n");
  echo("<tr><td class=\"row1\" align=\"left\" height=\"17\"><span class=\"gen\">Server kills</span></td>\n");
  echo("<td class=\"row2\" align=\"middle\" height=\"17\"><span class=\"gen\">$server[10]</span></td></tr>\n");
  echo("<tr><td class=\"row1\" align=\"left\" height=\"17\"><span class=\"gen\">Server splits</span></td>\n");
  echo("<td class=\"row2\" align=\"middle\" height=\"17\"><span class=\"gen\">$server[8]</span></td></tr>\n");
}
else
{
  echo("<tr><th class=\"thCornerL\" align=\"middle\" width=\"50%\" height=\"17\">Server</th>");
  echo("<th class=\"thCornerR\" align=\"middle\" height=\"17\">Current users</th>");
  echo("<th class=\"thCornerR\" align=\"middle\" height=\"17\">Max users</th>");
  echo("<th class=\"thCornerR\" align=\"middle\" height=\"17\">Opers</th>");
  echo("<th class=\"thCornerR\" align=\"middle\" height=\"17\">Oper kills</th></tr>");

  $result = mysql_query("SELECT * FROM server ORDER BY users DESC");
  while($server = mysql_fetch_row($result))
  {
    echo("<tr><td class=\"row1\" align=\"left\" height=\"17\"><span class=\"gen\"><a href=\"sentinel.php?server=$server[0]\">$server[0]</a></span></td>\n");
    echo("<td class=\"row2\" align=\"middle\" height=\"17\"><span class=\"gen\">$server[2]</span></td>\n");
    echo("<td class=\"row2\" align=\"middle\" height=\"17\"><span class=\"gen\">$server[3]</span></td>\n");
    echo("<td class=\"row3\" align=\"middle\" height=\"17\"><span class=\"gen\">$server[5]</span></td>\n");
    echo("<td class=\"row3\" align=\"middle\" height=\"17\"><span class=\"gen\">$server[9]</span></td></tr>\n");
  }
}
?>
        </tbody>
      </table>
    </td>
  </tr>
  </tbody>
</table>
<a href="sentinel.php">main</a>
</center>
</html>
<?php
  mysql_close($idsql);
?>

==> sentinel.v2.2.tar.gz: Sentinel/tools/www/sentinel.php <==
<?php
/*
 *  $Id: sentinel.php,v 1.7 2003/06/01 08:13:01 jeremy Exp $
 */

// MySQL Database
$mysql_server = "mysql.server";
$mysql_db     = "sentinel";
$mysql_user   = "user";
$mysql_passwd = "password";

// Hide hidden servers
// 1 = yes, 0 = no
$hide_servers	= 1;

// Determine $getstring
if (ereg("^5", phpversion()))
	$getstring = $_GET['server'];
else
	$getstring = $HTTP_GET_VARS['server'];


$server_id = (isset($getstring)) ? $getstring['server'] : '';


$idsql = mysql_connect($mysql_server, $mysql_user, $mysql_passwd);
mysql_select_db($mysql_db);
?>
<html>
<head>
<title>Sentinel Statistics</title>
<style type=text/css>
body { background-color: #E5E5E5; }
font,th,td,p { font-family: Verdana, Arial, Helvetica, sans-serif }
a:link,a:active,a:visited { text-decoration: none; color : #006699; }
a:hover { text-decoration: underline; color : #DD6900; }
.bodyline { background-color: #FFFFFF; border: 1px #98AAB1 solid; }
.maintitle { font-weight: bold; font-size: 22px; font-family: "Trebuchet MS",Verdana, Arial, Helvetica, sans-serif; text-decoration: none; line-height : 120%; color : #000000; }
.hline { background-color: #FFFFFF; border: 2px #006699 solid; }
.gen { font-size : 11px; color : #000000; }
td.row1	{ background-color: #EFEFEF; }
td.row2	{ background-color: #DEE3E7; }
td.row3	{ background-color: #D1D7DC; }
th { color: #FFA34F; font-size: 11px; font-weight : bold; background-color: #006699; height: 17px; background-image: url(img/cellpic.gif); }
th.thCornerL { border-width: 1px 0px 0px 1px; }
th.thCornerR { border-width: 1px 1px 0px 0px; }
</style>
</head>
<body bgcolor="#e5e5e5" text="#000000">
<center>
<table width="100%" cellspacing="0" cellpadding="10" border="0" align="center">
  <tbody>
  <tr>
    <td class="bodyline">
      <table cellSpacing=0 cellPadding=0 width="100%" border=0>
        <tbody>
        <tr>
          <td align="center"><span class="maintitle">
          <?php if (isset($HTTP_GET_VARS['server']))
                  echo("Sentinel Server $server_id Statistics");
                else
                  echo("Sentinel Network Statistics");
          ?>
          </span></td>
        </tr>
        </tbody>
      </table>
      <br>
      <table class="hline" cellSpacing="1" cellPadding="2" width="100%" border="0">
        <tbody>
<?php
if (isset($getstring))
{
  echo("<tr><th class=\"thCornerL\" align=\"middle\" width=\"80%\" height=\"17\">Field</th>");
  echo("<th class=\"thCornerR\" align=\"middle\" height=\"17\">Value</th></th>");

  if ($hide_servers == 1)
    $result = mysql_query("SELECT * FROM server WHERE name='$server_id' AND hidden=0 ORDER BY users DESC");
  else
    $result = mysql_query("SELECT * FROM server WHERE name='$server_id' ORDER BY users DESC");

  if (!isset($result))
    return;

  $server = mysql_fetch_row($result);

  $ninvis = abs($server[17] - $server[2]);

  echo("<tr><td class=\"row1\" align=\"left\" height=\"17\"><span class=\"gen\">Current users</span></td>\n");
  echo("<td class=\"row2\" align=\"middle\" height=\"17\"><span class=\"gen\">$server[2]</span></td></tr>\n");
  echo("<tr><td class=\"row1\" align=\"left\" height=\"17\"><span class=\"gen\">Max users</span></td>\n");
  echo("<td class=\"row2\" align=\"middle\" height=\"17\"><span class=\"gen\">$server[3]</span></td></tr>\n");
  echo("<tr><td class=\"row1\" align=\"left\" height=\"17\"><span class=\"gen\">Invisible users (+i)</span></td>\n");
  echo("<td class=\"row2\" align=\"middle\" height=\"17\"><span class=\"gen\">$server[17]</span></td></tr>\n");
  echo("<tr><td class=\"row1\" align=\"left\" height=\"17\"><span class=\"gen\">Not invisible users (-i)</span></td>\n");
  echo("<td class=\"row2\" align=\"middle\" height=\"17\"><span class=\"gen\">$ninvis</span></td></tr>\n");
  echo("<tr><td class=\"row1\" align=\"left\" height=\"17\"><span class=\"gen\">Away users</span></td>\n");
  echo("<td class=\"row2\" align=\"middle\" height=\"17\"><span class=\"gen\">$server[14]</span></td></tr>\n");
  echo("<tr><td class=\"row1\" align=\"left\" height=\"17\"><span class=\"gen\">Max away users</span></td>\n");
  echo("<td class=\"row2\" align=\"middle\" height=\"17\"><span class=\"gen\">$server[15]</span></td></tr>\n");
  echo("<tr><td class=\"row1\" align=\"left\" height=\"17\"><span class=\"gen\">Current opers</span></td>\n");
  echo("<td class=\"row2\" align=\"middle\" height=\"17\"><span class=\"gen\">$server[5]</span></td></tr>\n");
  echo("<tr><td class=\"row1\" align=\"left\" height=\"17\"><span class=\"gen\">Max opers</span></td>\n");
  echo("<td class=\"row2\" align=\"middle\" height=\"17\"><span class=\"gen\">$server[6]</span></td></tr>\n");
  echo("<tr><td class=\"row1\" align=\"left\" height=\"17\"><span class=\"gen\">Oper kills</span></td>\n");
  echo("<td class=\"row2\" align=\"middle\" height=\"17\"><span class=\"gen\">$server[9]</span></td></tr>\n");
  echo("<tr><td class=\"row1\" align=\"left\" height=\"17\"><span class=\"gen\">Server kills</span></td>\n");
  echo("<td class=\"row2\" align=\"middle\" height=\"17\"><span class=\"gen\">$server[10]</span></td></tr>\n");
  echo("<tr><td class=\"row1\" align=\"left\" height=\"17\"><span class=\"gen\">Server splits</span></td>\n");
  echo("<td class=\"row2\" align=\"middle\" height=\"17\"><span class=\"gen\">$server[8]</span></td></tr>\n");
}
else
{
  echo("<tr><th class=\"thCornerL\" align=\"middle\" width=\"50%\" height=\"17\">Server</th>");
  echo("<th class=\"thCornerR\" align=\"middle\" height=\"17\">Current users</th>");
  echo("<th class=\"thCornerR\" align=\"middle\" height=\"17\">Max users</th>");
  echo("<th class=\"thCornerR\" align=\"middle\" height=\"17\">Opers</th>");
  echo("<th class=\"thCornerR\" align=\"middle\" height=\"17\">Oper kills</th></tr>");

  if ($hide_servers == 1)
    $result = mysql_query("SELECT * FROM server WHERE hidden = 0 ORDER BY users DESC");
  else
    $result = mysql_query("SELECT * FROM server ORDER BY users DESC");
  while($server = mysql_fetch_row($result))
  {
    echo("<tr><td class=\"row1\" align=\"left\" height=\"17\"><span class=\"gen\"><a href=\"sentinel.php?server=$server[0]\">$server[0]</a></span></td>\n");
    echo("<td class=\"row2\" align=\"middle\" height=\"17\"><span class=\"gen\">$server[2]</span></td>\n");
    echo("<td class=\"row2\" align=\"middle\" height=\"17\"><span class=\"gen\">$server[3]</span></td>\n");
    echo("<td class=\"row3\" align=\"middle\" height=\"17\"><span class=\"gen\">$server[5]</span></td>\n");
    echo("<td class=\"row3\" align=\"middle\" height=\"17\"><span class=\"gen\">$server[9]</span></td></tr>\n");
  }
}
?>
        </tbody>
      </table>
    </td>
  </tr>
  </tbody>
</table>
<a href="sentinel.php">main</a>
</center>
</html>
<?php
  mysql_close($idsql);
?>
